@@ -17,6 +17,18 @@ sub new {
     return $self;
 }
 
+sub abstract {
+    return 'Test whether a module can be successfully loaded.';
+}
+
+sub add_to_cleanup {
+    return [ qw{ cover_db } ];
+}
+
+sub author {
+    return 'Thomas R. Wyant, III F<wyant at cpan dot org>';
+}
+
 sub build_requires {
     return +{
 	'lib'				=> 0,
@@ -25,13 +37,29 @@ sub build_requires {
     };
 }
 
+sub configure_requires {
+    return +{
+	'lib'	=> 0,
+	'strict'	=> 0,
+	'warnings'	=> 0,
+    };
+}
+
+sub dist_name {
+    return 'Test2-Tools-LoadModule';
+}
+
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
 }
 
+sub license {
+    return 'perl';
+}
+
 sub meta_merge {
-    my ( $self, @extra ) = @_;
+    my ( undef, @extra ) = @_;
     return {
 	'meta-spec'	=> {
 	    version	=> 2,
@@ -39,7 +67,8 @@ sub meta_merge {
 	dynamic_config	=> 1,
 	resources	=> {
 	    bugtracker	=> {
-		web	=> 'https://github.com/trwyant/perl-Test2-Tools-LoadModule/issues',
+		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Test2-Tools-LoadModule',
+		# web	=> 'https://github.com/trwyant/perl-Test2-Tools-LoadModule/issues',
 		mailto  => 'wyant@cpan.org',
 	    },
 	    license	=> 'http://dev.perl.org/licenses/',
@@ -53,6 +82,21 @@ sub meta_merge {
     };
 }
 
+
+sub module_name {
+    return 'Test2::Tools::LoadModule';
+}
+
+sub no_index {
+    return +{
+      directory => [
+                     'inc',
+                     't',
+                     'xt',
+                   ],
+    };
+}
+
 sub provides {
     -d 'lib'
 	or return;
@@ -87,6 +131,14 @@ sub requires_perl {
     return 5.008001;
 }
 
+sub script_files {
+    return [
+    ];
+}
+
+sub version_from {
+    return 'lib/Test2/Tools/LoadModule.pm';
+}
 
 1;
 
@@ -121,6 +173,19 @@ This class supports the following public methods:
 
 This method instantiates the class.
 
+=head2 abstract
+
+This method returns the distribution's abstract.
+
+=head2 add_to_cleanup
+
+This method returns a reference to an array of files to be added to the
+cleanup.
+
+=head2 author
+
+This method returns the name of the distribution author
+
 =head2 build_requires
 
  use YAML;
@@ -131,6 +196,20 @@ modules required to build the C<Test2::Tools::LoadModule> package, suitable for
 use in a F<Build.PL> C<build_requires> key, or a F<Makefile.PL>
 C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 
+=head2 configure_requires
+
+ use YAML;
+ print Dump( $meta->configure_requires() );
+
+This method returns a reference to a hash describing the modules
+required to configure the package, suitable for use in a F<Build.PL>
+C<configure_requires> key, or a F<Makefile.PL>
+C<< {META_MERGE}->{configure_requires} >> or C<CONFIGURE_REQUIRES> key.
+
+=head2 dist_name
+
+This method returns the distribution name.
+
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -142,6 +221,32 @@ C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 license
+
+This method returns the distribution's license.
+
+=head2 meta_merge
+
+ use YAML;
+ print Dump( $meta->meta_merge() );
+
+This method returns a reference to a hash describing the meta-data which
+has to be provided by making use of the builder's C<meta_merge>
+functionality. This includes the C<dynamic_config> and C<resources>
+data.
+
+Any arguments will be appended to the generated array.
+
+=head2 module_name
+
+This method returns the name of the module the distribution is based
+on.
+
+=head2 no_index
+
+This method returns the names of things which are not to be indexed
+by CPAN.
+
 =head2 provides
 
  use YAML;
@@ -171,11 +276,20 @@ may be added.
 
 This method returns the version of Perl required by the package.
 
+=head2 script_files
+
+This method returns a reference to an array containing the names of
+script files provided by this distribution. This array may be empty.
+
+=head2 version_from
+
+This method returns the name of the distribution file from which the
+distribution's version is to be derived.
+
 =head1 ATTRIBUTES
 
 This class has no public attributes.
 
-
 =head1 ENVIRONMENT
 
 =head2 MAKING_MODULE_DISTRIBUTION
@@ -184,10 +298,10 @@ This environment variable should be set to a true value if you are
 making a distribution. This ensures that no configuration-specific
 information makes it into F<META.yml>.
 
-
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test2-Tools-LoadModule>,
 L<https://github.com/trwyant/perl-Test2-Tools-LoadModule/issues>, or in
 electronic mail to the author.
 
